; This script compiles the ice core data at Frost Flowers site and makes a nc file out of that
; (c) Mahtuf - Martin vancop, UCL-ASTR, april 2007.
;--------------------------------------------------------------------------------------------------
; 2 eme version, pour jour no 1
; directory of the datafile
zversion='1.0' ; update this if you change stuff
zcomments='Initialization file for YROSIAE, Martin Vancoppenolle, Nov 2015'
ispol_dir=''

; dimensions of ice arrays
N = 31
z_i_TS = FLTARR(N)
t_i = FLTARR(N)
s_i = FLTARR(N)

;-------
; DATA
;-------
j_d = 263      ; Julian day
h_s = 0.01     ; Snow depth
h_i = 1.47     ; Ice thickness

h_i_TS = 1.55  ; Ice thickness, S-T core

z_i_TS = [ 2.5, 7.5, 12.5, 17.5, 22.5, 27.5, 32.5, 37.5, 42.5, 47.5, 52.5, 57.5, 62.5, 67.5, 72.5, 77.5, 82.5, 87.5, 92.5, 97.5, 102.5, 107.5, 112.5, 117.5, 122.5, 127.5, 132.5, 137.5, 142.5, 147.5, 152.5 ] / 100. * h_i / h_i_TS

s_i = [ 13, 11.5, 11.3, 9.7, 10.1, 9.5, 8.5, 7.6, 7.1, 6.5, 6.8, 6.2, 6.9, 6.7, 7, 7.6, 6.6, 8.2, 5.6, 4.5, 4.8, 4.8, 4.95, 5.1, 5, 4.8, 4.8, 4.7, 4.7, 5.5, 9.2 ]

t_i = [ -19.8, -18.7, -18.6, -18.2, -17.5, -16.8, -16.4, -16.2, -15.3, -14.7, -14.2, -13.5, -13.1, -12.6, -11.9, -11.5, -12.4, -11.5, -10.8, -10, -9.1, -8.6, -8.1, -7, -5.7, -4.7, -4.4, -3.7, -2.9, -2.4, -2.2 ] + 273.15

t_su = 263.000                        ; Surface temperature
oce_sal = 34.83                       ; Ocean salinity
t_bo = 273.15 - 0.054*oce_sal         ; Basal temperature
t_s = ( -19.8 + 273.15 + t_su ) / 2.  ; Snow temperature

;-------
; BGC 
;-------
rhoi = 917.;
rhow = 1020.;

h_i_nuts = 1.51
z_i_nuts = [ 0.125, 0.375, 0.6505, 1.035, 1.285, 1.46 ] * h_i / h_i_nuts
nox = [ 10., 6.17, 5.80, 5.98, 3.25, 16.10 ] * rhoi / rhow
po4 = [ 0.49, 0.38, 0.31, 0.31, 0.29, 0.72 ] * rhoi / rhow
dsi = [20.1, 18.03, 15.4, 12.78, 12.45, 29.98 ] * rhoi / rhow

h_i_chla = 1.52

z_i_chla = [ 0.5, 0.15, 0.25, 0.35, 0.45, 0.55, 0.65, 0.76, 0.87, 0.97, 1.07, 1.17, 1.27, 1.37, 1.47 ] * h_i / h_i_chla
chla = [ 0.14, 0.36, 0.12, 0.03, 0.14, 0.02, 0.01, 0.03, 0.03, 0.02, 0.19, 1.02, 1.03, 0.45, 13.28 ] * rhoi / rhow

;-------------------------------
; interpolate bgc on ST profile
;-------------------------------
nox_TS = INTERPOL(nox, z_i_nuts, z_i_TS)
po4_TS = INTERPOL(po4, z_i_nuts, z_i_TS)
dsi_TS = INTERPOL(dsi, z_i_nuts, z_i_TS)
chla_TS = INTERPOL(chla, z_i_chla, z_i_TS)

!P.MULTI=[0,2,2]
PLOT, nox, -z_i_nuts, PSYM = 1, thick = 2, color = 150, symsize = 2
OPLOT, nox_TS, -z_i_TS

PLOT, po4, -z_i_nuts, PSYM = 1, thick = 2, color = 150, symsize = 2
OPLOT, po4_TS, -z_i_TS

PLOT, dsi, -z_i_nuts, PSYM = 1, thick = 2, color = 150, symsize = 2
OPLOT, dsi_TS, -z_i_TS

PLOT, chla, -z_i_chla, PSYM = 1, thick = 2, color = 150, symsize = 2
OPLOT, chla_TS, -z_i_TS

chla_C = 0.05                ; winter chla_C
AoC_TS = chla_TS / chla_C / 12. ; divide by molar mass as well
eoC_TS = 0.1 * AoC_TS

; create AoN and eoN initialisation (fixed ratio N/C = 0.14)
AoN_TS = AoC_TS * 0.14 
eoN_TS = eoC_TS * 0.14

; create AoP and eoP initialisation (fixed ratio P/C = 0.0094)
AoP_TS = AoC_TS * 0.0094
eoP_TS = eoC_TS * 0.0094

;---------------
; Make the file
;---------------
filename='init_YROSIAE'
file_no = NCDF_CREATE( filename+'.nc', /CLOBBER )
NCDF_CONTROL, file_no, /VERBOSE

N_dim_no  = NCDF_DIMDEF( file_no, 'N', N ) 
scalar_dim_no  = NCDF_DIMDEF( file_no, 'scalar', 1 ) 

nlay_var_no = NCDF_VARDEF( file_no, 'nlay', [ scalar_dim_no ], /SHORT )
NCDF_ATTPUT, file_no, nlay_var_no, 'LONGNAME', 'Number of layers', /CHAR 
NCDF_ATTPUT, file_no, nlay_var_no, 'UNITS'   , '-', /CHAR 

j_d_var_no = NCDF_VARDEF( file_no, 'j_d', [ scalar_dim_no ], /FLOAT )
NCDF_ATTPUT, file_no, j_d_var_no, 'LONGNAME', 'julian day', /CHAR 
NCDF_ATTPUT, file_no, j_d_var_no, 'UNITS'   , 'd', /CHAR 

h_s_var_no = NCDF_VARDEF( file_no, 'h_s', [ scalar_dim_no ], /FLOAT )
NCDF_ATTPUT, file_no, h_s_var_no, 'LONGNAME', 'snow depth', /CHAR 
NCDF_ATTPUT, file_no, h_s_var_no, 'UNITS'   , 'm', /CHAR 

t_s_var_no = NCDF_VARDEF( file_no, 't_s', [ scalar_dim_no ], /FLOAT )
NCDF_ATTPUT, file_no, t_s_var_no, 'LONGNAME', 'snow temperature', /CHAR 
NCDF_ATTPUT, file_no, t_s_var_no, 'UNITS'   , 'K', /CHAR 

t_su_var_no = NCDF_VARDEF( file_no, 't_su', [ scalar_dim_no ], /FLOAT )
NCDF_ATTPUT, file_no, t_su_var_no, 'LONGNAME', 'surface temperature', /CHAR 
NCDF_ATTPUT, file_no, t_su_var_no, 'UNITS'   , 'K', /CHAR 

h_i_var_no = NCDF_VARDEF( file_no, 'h_i', [ scalar_dim_no ], /FLOAT )
NCDF_ATTPUT, file_no, h_i_var_no, 'LONGNAME', 'ice thickness', /CHAR 
NCDF_ATTPUT, file_no, h_i_var_no, 'UNITS'   , 'm', /CHAR 

z_i_var_no  = NCDF_VARDEF( file_no, 'z_i', [ N_dim_no ] , /FLOAT )
NCDF_ATTPUT, file_no, z_i_var_no, 'LONGNAME', 'depth in the ice', /CHAR 
NCDF_ATTPUT, file_no, z_i_var_no, 'UNITS'   , 'm', /CHAR 

t_i_var_no  = NCDF_VARDEF( file_no, 't_i', [ N_dim_no ] , /FLOAT )
NCDF_ATTPUT, file_no, t_i_var_no, 'LONGNAME', 'ice temperatures', /CHAR 
NCDF_ATTPUT, file_no, t_i_var_no, 'UNITS'   , 'K', /CHAR 

s_i_var_no  = NCDF_VARDEF( file_no, 's_i', [ N_dim_no ] , /FLOAT )
NCDF_ATTPUT, file_no, s_i_var_no, 'LONGNAME', 'ice salinities', /CHAR 
NCDF_ATTPUT, file_no, s_i_var_no, 'UNITS'   , 'psu', /CHAR 

dsi_var_no  = NCDF_VARDEF( file_no, 'dsi', [ N_dim_no ] , /FLOAT )
NCDF_ATTPUT, file_no, dsi_var_no, 'LONGNAME', 'dissolved si', /CHAR 
NCDF_ATTPUT, file_no, dsi_var_no, 'UNITS'   , 'mmol/m3', /CHAR 

nox_var_no  = NCDF_VARDEF( file_no, 'nox', [ N_dim_no ] , /FLOAT )
NCDF_ATTPUT, file_no, nox_var_no, 'LONGNAME', 'dissolved nox', /CHAR 
NCDF_ATTPUT, file_no, nox_var_no, 'UNITS'   , 'mmol/m3', /CHAR 

po4_var_no  = NCDF_VARDEF( file_no, 'po4', [ N_dim_no ] , /FLOAT )
NCDF_ATTPUT, file_no, po4_var_no, 'LONGNAME', 'dissolved po4', /CHAR 
NCDF_ATTPUT, file_no, po4_var_no, 'UNITS'   , 'mmol/m3', /CHAR 

AoC_var_no  = NCDF_VARDEF( file_no, 'AoC', [ N_dim_no ] , /FLOAT )
NCDF_ATTPUT, file_no, po4_var_no, 'LONGNAME', 'algal organic carbon', /CHAR 
NCDF_ATTPUT, file_no, po4_var_no, 'UNITS'   , 'mmol/m3', /CHAR 

eoC_var_no  = NCDF_VARDEF( file_no, 'eoC', [ N_dim_no ] , /FLOAT )
NCDF_ATTPUT, file_no, po4_var_no, 'LONGNAME', 'detrital organic carbon', /CHAR 
NCDF_ATTPUT, file_no, po4_var_no, 'UNITS'   , 'mmol/m3', /CHAR 

AoN_var_no = NCDF_VARDEF( file_no, 'AoN', [ N_dim_no ] , /FLOAT )
NCDF_ATTPUT, file_no, po4_var_no, 'LONGNAME', 'algal organic nitrogen', /CHAR
NCDF_ATTPUT, file_no, po4_var_no, 'UNITS'   , 'mmol/m3', /CHAR

eoN_var_no  = NCDF_VARDEF( file_no, 'eoN', [ N_dim_no ] , /FLOAT )
NCDF_ATTPUT, file_no, po4_var_no, 'LONGNAME', 'detrital organic nitrogen', /CHAR
NCDF_ATTPUT, file_no, po4_var_no, 'UNITS'   , 'mmol/m3', /CHAR

AoP_var_no = NCDF_VARDEF( file_no, 'AoP', [ N_dim_no ] , /FLOAT )
NCDF_ATTPUT, file_no, po4_var_no, 'LONGNAME', 'algal organic phosphate', /CHAR
NCDF_ATTPUT, file_no, po4_var_no, 'UNITS'   , 'mmol/m3', /CHAR

eoP_var_no  = NCDF_VARDEF( file_no, 'eoP', [ N_dim_no ] , /FLOAT )
NCDF_ATTPUT, file_no, po4_var_no, 'LONGNAME', 'detrital organic phosphate', /CHAR
NCDF_ATTPUT, file_no, po4_var_no, 'UNITS'   , 'mmol/m3', /CHAR


ztime = SYSTIME( /UTC)
NCDF_ATTPUT, file_no, "DATE", ztime, /GLOBAL, /CHAR
NCDF_ATTPUT, file_no, "version", zversion, /GLOBAL, /CHAR
NCDF_ATTPUT, file_no, "comments", zcomments, /GLOBAL, /CHAR

NCDF_CONTROL, file_no, /ENDEF

NCDF_VARPUT, file_no, nlay_var_no, N
NCDF_VARPUT, file_no, j_d_var_no, j_d
NCDF_VARPUT, file_no, h_s_var_no, h_s
NCDF_VARPUT, file_no, t_s_var_no, t_s
NCDF_VARPUT, file_no, t_su_var_no, t_su
NCDF_VARPUT, file_no, h_i_var_no, h_i
NCDF_VARPUT, file_no, z_i_var_no, z_i_TS
NCDF_VARPUT, file_no, t_i_var_no, t_i
NCDF_VARPUT, file_no, s_i_var_no, s_i
NCDF_VARPUT, file_no, dsi_var_no, dsi_TS
NCDF_VARPUT, file_no, nox_var_no, nox_TS
NCDF_VARPUT, file_no, po4_var_no, po4_TS
NCDF_VARPUT, file_no, AoC_var_no, AoC_TS
NCDF_VARPUT, file_no, eoC_var_no, eoC_TS
NCDF_VARPUT, file_no, AoN_var_no, AoN_TS
NCDF_VARPUT, file_no, eoN_var_no, eoN_TS
NCDF_VARPUT, file_no, AoP_var_no, AoP_TS
NCDF_VARPUT, file_no, eoP_var_no, eoP_TS

NCDF_CONTROL, file_no, /REDEF

;
NCDF_CLOSE, file_no
;
;------------------------------------------------------------------------------


;--------------------------------------------------------------------------------------------------
; end of the script
END
